@@ -722,7 +722,7 @@ def write_to_file(filteredSelectedContig,siteConfidence,out_dir,n):
                         hpvInsertion = eachContig[-2]
                         contigConfidence = 'Low Confidence Contig'
 
-                    if check_rep(contigSeq,key,n) == False:
+                    if check_rep(contigSeq,key,n) == True:
                         siteConfOutput = 'Poly(dn) in Contig'
                         contigConfidence = 'Poly(dn) in Contig'
                 
